Module: FlexCoerce
- Extended by:
- ModuleMethods
- Defined in:
- lib/y_support/flex_coerce.rb
Defined Under Namespace
Modules: ClassMethods, ModuleMethods Classes: FlexProxy
Instance Method Summary collapse
-
#coerce(first_operand) ⇒ Object
FlexCoerce provides coerce method that returns a proxy object and self.
-
#FlexProxy ⇒ Object
Method #FlexProxy is delegated to the host class, it returns the parametrized subclass of FlexCoerce::FlexProxy specific to the host class.
Methods included from ModuleMethods
customize_class, customize_module, included
Instance Method Details
#coerce(first_operand) ⇒ Object
FlexCoerce provides coerce method that returns a proxy object and self.
21 22 23 |
# File 'lib/y_support/flex_coerce.rb', line 21 def coerce first_operand return FlexProxy().of( first_operand ), self end |
#FlexProxy ⇒ Object
Method #FlexProxy is delegated to the host class, it returns the parametrized subclass of FlexCoerce::FlexProxy specific to the host class.
15 16 17 |
# File 'lib/y_support/flex_coerce.rb', line 15 def FlexProxy self.class.FlexProxy end |