Method: FlexCoerce::FlexProxy#method_missing
- Defined in:
- lib/y_support/flex_coerce/flex_proxy.rb
#method_missing(ß, arg) ⇒ Object
Proxy is essentially a single-use object. In its life, it receives a single message and returning the result. Unless the user specifically orders FlexProxy to respond to a method, it should raise TypeError.
36 37 38 39 40 41 42 |
# File 'lib/y_support/flex_coerce/flex_proxy.rb', line 36 def method_missing |